@@ -120,7 +120,7 @@ Glib::ustring TranslatableItem::get_title() const
       const Glib::ustring current_locale_language_id = Utils::locale_language_id(current_locale_id);
       for(type_map_locale_to_translations::const_iterator iter = m_map_translations.begin(); iter != m_map_translations.end(); ++iter)
       {
-        const Glib::ustring locale_id = iter->first;
+        const Glib::ustring& locale_id = iter->first;
         if(Utils::locale_language_id(locale_id) == current_locale_language_id)
         {
           if(!(iter->second.empty()))
@@ -256,6 +256,8 @@ Glib::ustring TranslatableItem::get_translatable_type_name_nontranslated(enumTra
     return "Relationship";
   else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
     return "Layout Item";
+  else if(item_type == TRANSLATABLE_TYPE_PRINT_LAYOUT)
+    return "Print Layout";
   else if(item_type == TRANSLATABLE_TYPE_REPORT)
     return "Report";
   else if(item_type == TRANSLATABLE_TYPE_TABLE)
@@ -284,6 +286,8 @@ Glib::ustring TranslatableItem::get_translatable_type_name(enumTranslatableItemT
     return _("Relationship");
   else if(item_type == TRANSLATABLE_TYPE_RELATIONSHIP)
     return _("Layout Item");
+  else if(item_type == TRANSLATABLE_TYPE_PRINT_LAYOUT)
+    return _("Print Layout");
   else if(item_type == TRANSLATABLE_TYPE_REPORT)
     return _("Report");
   else if(item_type == TRANSLATABLE_TYPE_TABLE)
