@@ -825,6 +825,7 @@ int Utils::dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id)
     show_help(id);
     result = dialog->run();
   }
+
   dialog->hide();
   return result;
 }
@@ -875,15 +876,14 @@ void Utils::show_help(const Glib::ustring& id)
   }
   catch(const std::exception& ex)
   {
-    std::string message(std::string(_("Could not display help: ")) + ex.what());
+    const Glib::ustring message = _("Could not display help: ") + Glib::ustring(ex.what());
     Gtk::MessageDialog dialog(message, false, Gtk::MESSAGE_ERROR);
     dialog.run();
   }
 #endif
 }
 
-
-void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
+void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window* parent, Gtk::MessageType message_type)
 {
 #ifdef GLOM_ENABLE_MAEMO
   // TODO_maemo: Map message_type to a senseful stock_id?
@@ -891,9 +891,49 @@ void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& mess
 #else
   Gtk::MessageDialog dialog("<b>" + title + "</b>", true /* markup */, message_type, Gtk::BUTTONS_OK);
   dialog.set_secondary_text(message);
-  dialog.set_transient_for(parent);
+  if(parent)
+    dialog.set_transient_for(*parent);
 #endif
+
   dialog.run();
 }
 
+void Utils::show_ok_dialog(const Glib::ustring& title, const Glib::ustring& message, Gtk::Window& parent, Gtk::MessageType message_type)
+{
+  show_ok_dialog(title, message, &parent, message_type);
+}
+
+namespace
+{
+
+static void on_window_hide(Glib::RefPtr<Glib::MainLoop> main_loop, sigc::connection handler_connection)
+{
+  handler_connection.disconnect(); //This should release a main_loop reference.
+  main_loop->quit();
+
+  //main_loop should be destroyed soon, because nothing else is using it.
+}
+
+} //anonymous namespace.
+
+void Utils::show_window_until_hide(Gtk::Window* window)
+{
+  if(!window)
+    return;
+
+  Glib::RefPtr<Glib::MainLoop> main_loop = Glib::MainLoop::create(false /* not running */);
+
+  //Stop the main_loop when the window is hidden:
+  sigc::connection handler_connection; //TODO: There seems to be a crash if this is on the same line.
+  handler_connection = window->signal_hide().connect( 
+    sigc::bind(
+      sigc::ptr_fun(&on_window_hide),
+      main_loop, handler_connection
+    ) );
+  
+  window->show();
+  main_loop->run(); //Run and block until it is stopped by the hide signal handler.
+}
+
+
 } //namespace Glom
